@@ -17,7 +17,7 @@ use App::VTide::Sessions;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('1.0.2');
+our $VERSION = version->new('1.0.3');
 our $NAME    = 'edit';
 our $OPTIONS =
   [ 'add|add-to-session|a', 'recurse|r!', 'test|T!', 'save|s=s', 'verbose|v+',
@@ -116,7 +116,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 1.0.2
+This documentation refers to App::VTide::Command::Edit version 1.0.3
 
 =head1 SYNOPSIS
 
@@ -124,6 +124,8 @@ This documentation refers to App::VTide::Command::Edit version 1.0.2
     vtide edit [--help|--man]
 
   OPTIONS:
+   -a --add-to-session
+                    Save this edit to the sessions file
    -r --recurse     Recurse through directories to find files
       --no-recurese Don't recurse throught directories
    -s --save[=]name Save edit options
